@@ -1,10 +1,11 @@
 # constants 
 # should be defined by autotools
 
-VERSION = '0.15.4'
-DATA_DIR = '/usr/share/gameconqueror'
+VERSION = '0.16.1'
+LIBDIR = '/usr/lib'
 LOCALEDIR = '/usr/share/locale'
 GETTEXT_PACKAGE = 'GameConqueror'
+PACKAGE_BUGREPORT = 'https://github.com/scanmem/scanmem'
 
 SETTINGS = {'scan_data_type':'int32'
            ,'lock_data_type':'int32'
